<?
	require('./include/index.php.inc');
        require('./include/conf.php.inc');
?>
<?='<?xml version="1.0" encoding="ISO-8859-15"?>'?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="nl">
	<head>
		<title>http://<?=$_SERVER["SERVER_NAME"] . $_SERVER["REQUEST_URI"]?></title>
		<meta name="Author" content="Micha&euml;l Hompus" />
		<meta name="date" content="2002-08-01T00:40:00+02:00" />
		<style type="text/css">
			@import url('<?=$XPIndexDir?>/css/index.php');
		</style>
	</head>
	<body>
		<table cellspacing="0" cellpadding="0">
			<thead>
				<tr>
					<th class="left">Naam</th>
					<th class="right">Grootte</th>
					<th class="left">Type</th>
					<th class="left">Gewijzigd op</th>
					<th class="left">Eigenaar</th>
					<th class="left">Groep</th>
					<th class="left">Kenmerken</th>
					<th class="fill">&nbsp;</th>
				</tr>
			</thead>
			<tbody>
<?ParseDir($_SERVER["DOCUMENT_ROOT"] . $_SERVER["REQUEST_URI"]);?>
			</tbody>
		</table>
	</body>
</html>
