<?php

$XPIndexDir = '/XPindex';

$knownfiletypes = Array(
       	'00000000000' => 'Bovenliggende map',
        '00000000001' => 'Bestandsmap',
       	'xls'   => 'Microsoft Excel-werkblad',
        'doc'   => 'Microsoft Word-document',
       	'dll'   => 'Toepassingsuitbreiding',
        'db'    => 'Databasebestand',
       	'exe'   => 'Toepassing',
        'ini'   => 'Configuratie-instellingen',
        'bmp'	=> 'Bitmapafbeelding',
        'gif'	=> 'GIF-afbeelding',
        'jpg'	=> 'JPEG-afbeelding',
        'jpeg'	=> 'JPEG-afbeelding',
        'png'	=> 'PNG-afbeelding',
        'htm'	=> 'HTML-document',
        'html'	=> 'HTML-document',
        'txt'	=> 'Tekstdocument'
);

$icons = Array(
        '00000000000' => 'mapup.png',
        '00000000001' => 'map.png',
        'db'    => 'dll.png',
        'dll'   => 'dll.png',
        'gz'    => 'zip.png',
        'zip'   => 'zip.png',
        'html'  => 'html.png',
        'htm'   => 'html.png',
        'shtm'  => 'html.png',
        'shtml' => 'html.png',
        'ini'   => 'ini.png',
        'bmp'   => 'bmp.png',
        'gif'   => 'gif.png',
        'jpg'   => 'jpg.png',
        'png'   => 'gif.png',
        'txt'   => 'txt.png'
);

?>
